censor_it library

Support for doing something awesome.

More dartdocs go here.

Classes

CensorIt
pattern is the censor pattern to use. Defaults to LanguagePattern.all.
CensorItBuilder
Creates an instance with custom replacement function.
CensorItMask
Creates an instance that masks profanity by repeating a character.
CensorItRandom
Creates an instance with random character replacement.
CensorItReplace
Creates an instance that replaces profanity with a fixed string.
CensorPattern
Abstract interface for censor patterns.
CustomPattern
Internal class for custom patterns created from RegExp.
DePattern
German profanity pattern.
EnPattern
English profanity pattern.
EsPattern
Spanish profanity pattern.
FiPattern
Finnish profanity pattern.
FrPattern
French profanity pattern.
ItPattern
Italian profanity pattern.
KoPattern
Korean profanity pattern.
KzPattern
Kazakh profanity pattern.
LanguagePattern
Base class for language-specific censor patterns.
LtPattern
Lithuanian profanity pattern.
LvPattern
Latvian profanity pattern.
MultiCensorPattern
Internal class for multiple language patterns.
PlPattern
Polish profanity pattern.
PtPattern
Portuguese profanity pattern.
RuPattern
Russian profanity pattern.
SePattern
Swedish profanity pattern.
UaPattern
Ukrainian profanity pattern.
ZhPattern
Chinese profanity pattern.

Extensions

CensoredX on String
Returns the censored version of this string using random characters.
GetMatchesX on CensorIt
Extension for getting regex matches from CensorIt.

Typedefs

ReplacementBuilder = String Function(String word)
Signature for custom replacement function.