FrPattern class final

French profanity pattern.

Implemented types

Constructors

FrPattern()
French profanity pattern.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
locale String
Locale code (e.g., 'en', 'ru', 'lv').
no setteroverride
name String
Human-readable language name.
no setteroverride
regExp RegExp
Returns a regular expression for profanity detection.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited